import { createVNode as _createVNode } from "vue";
// Styles
import "./VAvatar.sass"; // Composables

import { makeBorderRadiusProps, useBorderRadius } from "../../composables/border-radius.mjs";
import { makeSizeProps, useSize } from "../../composables/size.mjs";
import { makeTagProps } from "../../composables/tag.mjs";
import { useBackgroundColor } from "../../composables/color.mjs"; // Utilities

import { defineComponent, toRef } from 'vue';
export default defineComponent({
  name: 'VAvatar',
  props: { ...makeBorderRadiusProps(),
    ...makeSizeProps(),
    ...makeTagProps(),
    color: String,
    left: Boolean,
    right: Boolean
  },

  setup(props, {
    slots
  }) {
    const {
      backgroundColorClasses,
      backgroundColorStyles
    } = useBackgroundColor(toRef(props, 'color'));
    const {
      borderRadiusClasses
    } = useBorderRadius(props);
    const {
      sizeClasses,
      sizeStyles
    } = useSize(props, 'v-avatar');
    return () => _createVNode(props.tag, {
      "class": ['v-avatar', {
        'v-avatar--left': props.left,
        'v-avatar--right': props.right
      }, backgroundColorClasses.value, borderRadiusClasses.value, sizeClasses.value],
      "style": [backgroundColorStyles.value, sizeStyles.value]
    }, {
      default: () => [slots.default == null ? void 0 : slots.default()]
    }, 8, ["class", "style"]);
  }

});
//# sourceMappingURL=VAvatar.mjs.map