import { createVNode as _createVNode, resolveDirective as _resolveDirective } from "vue";
// Styles
import "./VSheet.sass"; // Composables

import { makeBorderProps, useBorder } from "../../composables/border.mjs";
import { makeBorderRadiusProps, useBorderRadius } from "../../composables/border-radius.mjs";
import { makeDimensionProps, useDimension } from "../../composables/dimensions.mjs";
import { makeElevationProps, useElevation } from "../../composables/elevation.mjs";
import { makePositionProps, usePosition } from "../../composables/position.mjs";
import { makeTagProps } from "../../composables/tag.mjs";
import { useBackgroundColor } from "../../composables/color.mjs";
import { useTheme } from "../../composables/theme.mjs"; // Utilities

import { defineComponent, toRef } from 'vue';
import makeProps from "../../util/makeProps.mjs";
export default defineComponent({
  name: 'VSheet',
  props: makeProps({ ...makeBorderProps(),
    ...makeBorderRadiusProps(),
    ...makeDimensionProps(),
    ...makeElevationProps(),
    ...makePositionProps(),
    ...makeTagProps(),
    color: String
  }),

  setup(props, {
    slots
  }) {
    const {
      themeClasses
    } = useTheme();
    const {
      backgroundColorClasses,
      backgroundColorStyles
    } = useBackgroundColor(toRef(props, 'color'));
    const {
      borderClasses
    } = useBorder(props, 'v-sheet');
    const {
      borderRadiusClasses
    } = useBorderRadius(props);
    const {
      dimensionStyles
    } = useDimension(props);
    const {
      elevationClasses
    } = useElevation(props);
    const {
      positionClasses,
      positionStyles
    } = usePosition(props, 'v-sheet');
    return () => _createVNode(props.tag, {
      "class": ['v-sheet', themeClasses.value, backgroundColorClasses.value, borderClasses.value, borderRadiusClasses.value, elevationClasses.value, positionClasses.value],
      "style": [backgroundColorStyles.value, dimensionStyles.value, positionStyles.value]
    }, { ...slots,
      _: 1
    }, 8, ["class", "style"]);
  }

});
//# sourceMappingURL=VSheet.mjs.map