import { createVNode as _createVNode, resolveDirective as _resolveDirective } from "vue";
// Styles
import "./VSystemBar.sass"; // Composables

import { makeBorderProps, useBorder } from "../../composables/border.mjs";
import { makeBorderRadiusProps, useBorderRadius } from "../../composables/border-radius.mjs";
import { makeDimensionProps, useDimension } from "../../composables/dimensions.mjs";
import { makeElevationProps, useElevation } from "../../composables/elevation.mjs";
import { makePositionProps, usePosition } from "../../composables/position.mjs";
import { makeTagProps } from "../../composables/tag.mjs";
import { useTheme } from "../../composables/theme.mjs"; // Utilities

import { defineComponent } from 'vue';
import makeProps from "../../util/makeProps.mjs";
export default defineComponent({
  name: 'VSystemBar',
  props: makeProps({
    lightsOut: Boolean,
    window: Boolean,
    ...makeBorderProps(),
    ...makeBorderRadiusProps(),
    ...makeDimensionProps(),
    ...makeElevationProps(),
    ...makePositionProps(),
    ...makeTagProps()
  }),

  setup(props, {
    slots
  }) {
    const {
      themeClasses
    } = useTheme();
    const {
      borderClasses
    } = useBorder(props, 'v-system-bar');
    const {
      borderRadiusClasses
    } = useBorderRadius(props);
    const {
      dimensionStyles
    } = useDimension(props);
    const {
      elevationClasses
    } = useElevation(props);
    const {
      positionClasses,
      positionStyles
    } = usePosition(props, 'v-system-bar');
    return () => _createVNode(props.tag, {
      "class": [{
        'v-system-bar': true,
        'v-system-bar--lights-out': props.lightsOut,
        'v-system-bar--window': props.window
      }, themeClasses.value, borderClasses.value, borderRadiusClasses.value, elevationClasses.value, positionClasses.value],
      "style": [dimensionStyles.value, positionStyles.value]
    }, { ...slots,
      _: 1
    }, 8, ["class", "style"]);
  }

});
//# sourceMappingURL=VSystemBar.mjs.map