// Setup
import { computed } from 'vue';
import { convertToUnit } from "../util/index.mjs";
import propsFactory from "../util/propsFactory.mjs";
const predefinedSizes = ['x-small', 'small', 'default', 'large', 'x-large'];
// Props
export const makeSizeProps = propsFactory({
  size: {
    type: [String, Number],
    default: 'default'
  }
}, 'size'); // Effect

export function useSize(props, name) {
  const sizeClasses = computed(() => {
    return predefinedSizes.includes(props.size) ? "".concat(name, "--size-").concat(props.size) : null;
  });
  const sizeStyles = computed(() => {
    return !predefinedSizes.includes(props.size) && props.size ? {
      width: convertToUnit(props.size),
      height: convertToUnit(props.size)
    } : null;
  });
  return {
    sizeClasses,
    sizeStyles
  };
}
//# sourceMappingURL=size.mjs.map